@@ -13,15 +13,17 @@
 #define EbAppConfig_h
 
 #include <stdio.h>
+#include <stdbool.h>
 
 #include "EbSvtAv1Enc.h"
 
-typedef struct EbAppContext_ EbAppContext;
-
 #ifdef _WIN32
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
 #define fseeko _fseeki64
 #define ftello _ftelli64
 #endif
+
 // Define Cross-Platform 64-bit fseek() and ftell()
 /** The AppExitConditionType type is used to define the App main loop exit
 conditions.
@@ -44,78 +46,8 @@ typedef enum EncPass {
     MAX_ENC_PASS = 3,
 } EncPass;
 
-/** The EbPtr type is intended to be used to pass pointers to and from the svt
-API.  This is a 32 bit pointer and is aligned on a 32 bit word boundary.
-*/
-typedef void *EbPtr;
-
 #define WARNING_LENGTH 100
 
-// memory map to be removed and replaced by malloc / free
-typedef enum EbPtrType {
-    EB_N_PTR     = 0, // malloc'd pointer
-    EB_A_PTR     = 1, // malloc'd pointer aligned
-    EB_MUTEX     = 2, // mutex
-    EB_SEMAPHORE = 3, // semaphore
-    EB_THREAD    = 4 // thread handle
-} EbPtrType;
-typedef struct EbMemoryMapEntry {
-    EbPtr     ptr; // points to a memory pointer
-    EbPtrType ptr_type; // pointer type
-} EbMemoryMapEntry;
-
-extern EbMemoryMapEntry *app_memory_map; // App Memory table
-extern uint32_t         *app_memory_map_index; // App Memory index
-extern uint64_t         *total_app_memory; // App Memory malloc'd
-extern uint32_t          app_malloc_count;
-
-#define MAX_APP_NUM_PTR (0x186A0 << 2) // Maximum number of pointers to be allocated for the app
-
-#define EB_APP_MALLOC(type, pointer, n_elements, pointer_class, return_type) \
-    pointer = (type)malloc(n_elements);                                      \
-    if (pointer == (type)NULL) {                                             \
-        return return_type;                                                  \
-    } else {                                                                 \
-        app_memory_map[*(app_memory_map_index)].ptr_type = pointer_class;    \
-        app_memory_map[(*(app_memory_map_index))++].ptr  = pointer;          \
-        if (n_elements % 8 == 0) {                                           \
-            *total_app_memory += (n_elements);                               \
-        } else {                                                             \
-            *total_app_memory += ((n_elements) + (8 - ((n_elements) % 8)));  \
-        }                                                                    \
-    }                                                                        \
-    if (*(app_memory_map_index) >= MAX_APP_NUM_PTR) {                        \
-        return return_type;                                                  \
-    }                                                                        \
-    app_malloc_count++;
-
-#define EB_APP_MALLOC_NR(type, pointer, n_elements, pointer_class, return_type) \
-    (void)return_type;                                                          \
-    pointer = (type)malloc(n_elements);                                         \
-    if (pointer == (type)NULL) {                                                \
-        return_type = EB_ErrorInsufficientResources;                            \
-        fprintf(stderr, "Malloc has failed due to insuffucient resources");     \
-        return;                                                                 \
-    } else {                                                                    \
-        app_memory_map[*(app_memory_map_index)].ptr_type = pointer_class;       \
-        app_memory_map[(*(app_memory_map_index))++].ptr  = pointer;             \
-        if (n_elements % 8 == 0) {                                              \
-            *total_app_memory += (n_elements);                                  \
-        } else {                                                                \
-            *total_app_memory += ((n_elements) + (8 - ((n_elements) % 8)));     \
-        }                                                                       \
-    }                                                                           \
-    if (*(app_memory_map_index) >= MAX_APP_NUM_PTR) {                           \
-        return_type = EB_ErrorInsufficientResources;                            \
-        fprintf(stderr, "Malloc has failed due to insuffucient resources");     \
-        return;                                                                 \
-    }                                                                           \
-    app_malloc_count++;
-
-#define EB_APP_MEMORY()                                                        \
-    fprintf(stderr, "Total Number of Mallocs in App: %u\n", app_malloc_count); \
-    fprintf(stderr, "Total App Memory: %.2lf KB\n\n", *total_app_memory / (double)1024);
-
 #define MAX_CHANNEL_NUMBER 6U
 #define MAX_NUM_TOKENS 210
 
@@ -137,7 +69,6 @@ typedef struct EbPerformanceContext {
 
     uint64_t total_latency;
     uint32_t max_latency;
-
     uint64_t starts_time;
     uint64_t startu_time;
     uint64_t frame_count;
@@ -163,13 +94,16 @@ typedef struct EbPerformanceContext {
 } EbPerformanceContext;
 
 typedef struct MemMapFile {
-    uint8_t  enable; //enable mem mapped file
-    int64_t  file_size; //size of the input file
-    int32_t  align_mask; //page size alignment mask
-    int32_t  fd; //file descriptor
-    int64_t  y4m_seq_hdr; //y4m seq length
+    bool     enable; //enable mem mapped file
+    size_t   file_size; //size of the input file
+    uint64_t align_mask; //page size alignment mask
+    int      fd; //file descriptor
+    size_t   y4m_seq_hdr; //y4m seq length
     size_t   y4m_frm_hdr; //y4m frame length
     uint64_t file_frame_it; //frame iterator within the input file
+#ifdef _WIN32
+    HANDLE map_handle; //file mapping handle
+#endif
 } MemMapFile;
 
 // list of frames that are forced to be key frames
@@ -209,7 +143,10 @@ typedef struct EbConfig {
     uint32_t input_padded_height;
     // -1 indicates unknown (auto-detect at earliest opportunity)
     // auto-detect is performed on load for files and at end of stream for pipes
-    int64_t   frames_to_be_encoded;
+    int64_t frames_to_be_encoded;
+    int64_t frames_to_be_skipped;
+    bool    need_to_skip;
+
     int32_t   frames_encoded;
     int32_t   buffered_input;
     uint8_t **sequence_buffer;
@@ -226,17 +163,32 @@ typedef struct EbConfig {
     uint64_t ivf_count;
 
     struct forced_key_frames forced_keyframes;
+
     /****************************************
      * On-the-fly Testing
      ****************************************/
     Bool eos_flag;
 
     EbSvtAv1EncConfiguration config;
+    // Output Ports Active Flags
+    AppPortActiveType output_stream_port_active;
+
+    // Component Handle
+    EbComponentType *svt_encoder_handle;
+
+    // Buffer Pools
+    EbBufferHeaderType *input_buffer_pool;
+    EbBufferHeaderType *recon_buffer;
+
+    FILE         *roi_map_file;
+    SvtAv1RoiMap *roi_map;
+
+    // Instance Index
+    uint8_t instance_idx;
 } EbConfig;
 
 typedef struct EncChannel {
-    EbConfig            *config; // Encoder Configuration
-    EbAppContext        *app_callback; // Instances App callback date
+    EbConfig            *app_cfg; // Encoder Configuration
     EbErrorType          return_error; // Error Handling
     AppExitConditionType exit_cond_output; // Processing loop exit condition
     AppExitConditionType exit_cond_recon; // Processing loop exit condition
@@ -255,16 +207,15 @@ typedef struct EncApp {
     SvtAv1FixedBuf rc_twopasses_stats;
 } EncApp;
 EbConfig *svt_config_ctor();
-void      svt_config_dtor(EbConfig *config_ptr);
+void      svt_config_dtor(EbConfig *app_cfg);
 
 EbErrorType     enc_channel_ctor(EncChannel *c);
 void            enc_channel_dctor(EncChannel *c, uint32_t inst_cnt);
-EbErrorType     read_command_line(int32_t argc, char *const argv[], EncChannel *channels,
-                                  uint32_t num_channels);
+EbErrorType     read_command_line(int32_t argc, char *const argv[], EncChannel *channels, uint32_t num_channels);
 int             get_version(int argc, char *argv[]);
 extern uint32_t get_help(int32_t argc, char *const argv[]);
 extern uint32_t get_number_of_channels(int32_t argc, char *const argv[]);
 uint32_t        get_passes(int32_t argc, char *const argv[], EncPass enc_pass[MAX_ENC_PASS]);
-EbErrorType handle_stats_file(EbConfig *config, EncPass pass, const SvtAv1FixedBuf *rc_stats_buffer,
-                              uint32_t channel_number);
+EbErrorType     handle_stats_file(EbConfig *app_cfg, EncPass pass, const SvtAv1FixedBuf *rc_stats_buffer,
+                                  uint32_t channel_number);
 #endif //EbAppConfig_h
