@@ -17,8 +17,8 @@
 // -----------------------------------------------------------------------------
 // H_PRED
 
-void svt_aom_highbd_h_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                         const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                         int32_t bd) {
     const __m128i left_u16 = _mm_loadl_epi64((const __m128i *)left);
     const __m128i row0     = _mm_shufflelo_epi16(left_u16, 0x0);
     const __m128i row1     = _mm_shufflelo_epi16(left_u16, 0x55);
@@ -35,16 +35,16 @@ void svt_aom_highbd_h_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride, const
     _mm_storel_epi64((__m128i *)dst, row3);
 }
 
-void svt_aom_highbd_h_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                         const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                         int32_t bd) {
     svt_aom_highbd_h_predictor_4x4_sse2(dst, stride, above, left, bd);
     dst += stride << 2;
     left += 4;
     svt_aom_highbd_h_predictor_4x4_sse2(dst, stride, above, left, bd);
 }
 
-void svt_aom_highbd_h_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                          const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                          int32_t bd) {
     svt_aom_highbd_h_predictor_4x4_sse2(dst, stride, above, left, bd);
     dst += stride << 2;
     left += 4;
@@ -57,8 +57,8 @@ void svt_aom_highbd_h_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const
     svt_aom_highbd_h_predictor_4x4_sse2(dst, stride, above, left, bd);
 }
 
-void svt_aom_highbd_h_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                         const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                         int32_t bd) {
     const __m128i left_u16 = _mm_loadu_si128((const __m128i *)left);
     const __m128i row0     = _mm_shufflelo_epi16(left_u16, 0x0);
     const __m128i row1     = _mm_shufflelo_epi16(left_u16, 0x55);
@@ -75,8 +75,8 @@ void svt_aom_highbd_h_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const
     _mm_storeu_si128((__m128i *)dst, _mm_unpacklo_epi64(row3, row3));
 }
 
-void svt_aom_highbd_h_predictor_8x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                         const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_8x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                         int32_t bd) {
     const __m128i left_u16 = _mm_loadu_si128((const __m128i *)left);
     const __m128i row0     = _mm_shufflelo_epi16(left_u16, 0x0);
     const __m128i row1     = _mm_shufflelo_epi16(left_u16, 0x55);
@@ -105,16 +105,16 @@ void svt_aom_highbd_h_predictor_8x8_sse2(uint16_t *dst, ptrdiff_t stride, const
     _mm_storeu_si128((__m128i *)dst, _mm_unpackhi_epi64(row7, row7));
 }
 
-void svt_aom_highbd_h_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                          const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                          int32_t bd) {
     svt_aom_highbd_h_predictor_8x8_sse2(dst, stride, above, left, bd);
     dst += stride << 3;
     left += 8;
     svt_aom_highbd_h_predictor_8x8_sse2(dst, stride, above, left, bd);
 }
 
-void svt_aom_highbd_h_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                          const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                          int32_t bd) {
     svt_aom_highbd_h_predictor_8x8_sse2(dst, stride, above, left, bd);
     dst += stride << 3;
     left += 8;
@@ -161,15 +161,15 @@ static INLINE void h_predictor_16x8(uint16_t *dst, ptrdiff_t stride, const uint1
     h_store_16_unpackhi(&dst, stride, &row7);
 }
 
-void svt_aom_highbd_h_predictor_16x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                          const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_16x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                          int32_t bd) {
     (void)above;
     (void)bd;
     h_predictor_16x8(dst, stride, left);
 }
 
-void svt_aom_highbd_h_predictor_16x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                           const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_16x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                           int32_t bd) {
     int32_t i;
     (void)above;
     (void)bd;
@@ -180,8 +180,8 @@ void svt_aom_highbd_h_predictor_16x16_sse2(uint16_t *dst, ptrdiff_t stride, cons
     }
 }
 
-void svt_aom_highbd_h_predictor_16x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                           const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_16x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                           int32_t bd) {
     int32_t i;
     (void)above;
     (void)bd;
@@ -230,8 +230,8 @@ static INLINE void h_predictor_32x8(uint16_t *dst, ptrdiff_t stride, const uint1
     h_store_32_unpackhi(&dst, stride, &row7);
 }
 
-void svt_aom_highbd_h_predictor_32x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                           const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_32x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                           int32_t bd) {
     int32_t i;
     (void)above;
     (void)bd;
@@ -242,8 +242,8 @@ void svt_aom_highbd_h_predictor_32x16_sse2(uint16_t *dst, ptrdiff_t stride, cons
     }
 }
 
-void svt_aom_highbd_h_predictor_32x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                           const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_h_predictor_32x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                           int32_t bd) {
     int32_t i;
     (void)above;
     (void)bd;
@@ -259,16 +259,14 @@ void svt_aom_highbd_h_predictor_32x32_sse2(uint16_t *dst, ptrdiff_t stride, cons
 
 // 4x4
 
-static INLINE void dc_store_4xh(uint16_t *dst, ptrdiff_t stride, int32_t height,
-                                const __m128i *dc) {
+static INLINE void dc_store_4xh(uint16_t *dst, ptrdiff_t stride, int32_t height, const __m128i *dc) {
     const __m128i dc_dup = _mm_shufflelo_epi16(*dc, 0x0);
     int32_t       i;
     for (i = 0; i < height; ++i, dst += stride) _mm_storel_epi64((__m128i *)dst, dc_dup);
 }
 
-void svt_aom_highbd_dc_left_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride,
-                                               const uint16_t *above, const uint16_t *left,
-                                               int32_t bd) {
+void svt_aom_highbd_dc_left_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                               const uint16_t *left, int32_t bd) {
     const __m128i two = _mm_cvtsi32_si128(2);
     const __m128i sum = dc_sum_4(left);
     const __m128i dc  = _mm_srli_epi16(_mm_add_epi16(sum, two), 2);
@@ -277,9 +275,8 @@ void svt_aom_highbd_dc_left_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride,
     dc_store_4xh(dst, stride, 4, &dc);
 }
 
-void svt_aom_highbd_dc_top_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride,
-                                              const uint16_t *above, const uint16_t *left,
-                                              int32_t bd) {
+void svt_aom_highbd_dc_top_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                              const uint16_t *left, int32_t bd) {
     const __m128i two = _mm_cvtsi32_si128(2);
     const __m128i sum = dc_sum_4(above);
     const __m128i dc  = _mm_srli_epi16(_mm_add_epi16(sum, two), 2);
@@ -288,9 +285,8 @@ void svt_aom_highbd_dc_top_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride,
     dc_store_4xh(dst, stride, 4, &dc);
 }
 
-void svt_aom_highbd_dc_128_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride,
-                                              const uint16_t *above, const uint16_t *left,
-                                              int32_t bd) {
+void svt_aom_highbd_dc_128_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                              const uint16_t *left, int32_t bd) {
     const __m128i dc = _mm_cvtsi32_si128(1 << (bd - 1));
     (void)above;
     (void)left;
@@ -300,9 +296,8 @@ void svt_aom_highbd_dc_128_predictor_4x4_sse2(uint16_t *dst, ptrdiff_t stride,
 // -----------------------------------------------------------------------------
 // 4x8
 
-void svt_aom_highbd_dc_left_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride,
-                                               const uint16_t *above, const uint16_t *left,
-                                               int32_t bd) {
+void svt_aom_highbd_dc_left_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                               const uint16_t *left, int32_t bd) {
     const __m128i sum  = dc_sum_8(left);
     const __m128i four = _mm_cvtsi32_si128(4);
     const __m128i dc   = _mm_srli_epi16(_mm_add_epi16(sum, four), 3);
@@ -311,9 +306,8 @@ void svt_aom_highbd_dc_left_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride,
     dc_store_4xh(dst, stride, 8, &dc);
 }
 
-void svt_aom_highbd_dc_top_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride,
-                                              const uint16_t *above, const uint16_t *left,
-                                              int32_t bd) {
+void svt_aom_highbd_dc_top_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                              const uint16_t *left, int32_t bd) {
     const __m128i two = _mm_cvtsi32_si128(2);
     const __m128i sum = dc_sum_4(above);
     const __m128i dc  = _mm_srli_epi16(_mm_add_epi16(sum, two), 2);
@@ -322,9 +316,8 @@ void svt_aom_highbd_dc_top_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride,
     dc_store_4xh(dst, stride, 8, &dc);
 }
 
-void svt_aom_highbd_dc_128_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride,
-                                              const uint16_t *above, const uint16_t *left,
-                                              int32_t bd) {
+void svt_aom_highbd_dc_128_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                              const uint16_t *left, int32_t bd) {
     const __m128i dc = _mm_cvtsi32_si128(1 << (bd - 1));
     (void)above;
     (void)left;
@@ -348,9 +341,8 @@ static INLINE __m128i dc_sum_16(const uint16_t *const src) {
     return sum;
 }
 
-void svt_aom_highbd_dc_left_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride,
-                                                const uint16_t *above, const uint16_t *left,
-                                                int32_t bd) {
+void svt_aom_highbd_dc_left_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                                const uint16_t *left, int32_t bd) {
     const __m128i sum   = dc_sum_16(left);
     const __m128i eight = _mm_cvtsi32_si128(8);
     const __m128i dc    = _mm_srli_epi16(_mm_add_epi16(sum, eight), 4);
@@ -359,9 +351,8 @@ void svt_aom_highbd_dc_left_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride,
     dc_store_4xh(dst, stride, 16, &dc);
 }
 
-void svt_aom_highbd_dc_top_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride,
-                                               const uint16_t *above, const uint16_t *left,
-                                               int32_t bd) {
+void svt_aom_highbd_dc_top_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                               const uint16_t *left, int32_t bd) {
     const __m128i two = _mm_cvtsi32_si128(2);
     const __m128i sum = dc_sum_4(above);
     const __m128i dc  = _mm_srli_epi16(_mm_add_epi16(sum, two), 2);
@@ -370,9 +361,8 @@ void svt_aom_highbd_dc_top_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride,
     dc_store_4xh(dst, stride, 16, &dc);
 }
 
-void svt_aom_highbd_dc_128_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride,
-                                               const uint16_t *above, const uint16_t *left,
-                                               int32_t bd) {
+void svt_aom_highbd_dc_128_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                               const uint16_t *left, int32_t bd) {
     const __m128i dc = _mm_cvtsi32_si128(1 << (bd - 1));
     (void)above;
     (void)left;
@@ -382,8 +372,7 @@ void svt_aom_highbd_dc_128_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride,
 // -----------------------------------------------------------------------------
 // 8xh
 
-static INLINE void dc_store_8xh(uint16_t *dst, ptrdiff_t stride, int32_t height,
-                                const __m128i *dc) {
+static INLINE void dc_store_8xh(uint16_t *dst, ptrdiff_t stride, int32_t height, const __m128i *dc) {
     const __m128i dc_dup_lo = _mm_shufflelo_epi16(*dc, 0);
     const __m128i dc_dup    = _mm_unpacklo_epi64(dc_dup_lo, dc_dup_lo);
     int32_t       i;
@@ -393,33 +382,29 @@ static INLINE void dc_store_8xh(uint16_t *dst, ptrdiff_t stride, int32_t height,
 // -----------------------------------------------------------------------------
 // DC_TOP
 
-static INLINE void dc_top_predictor_8xh(uint16_t *dst, ptrdiff_t stride, int32_t height,
-                                        const uint16_t *above) {
+static INLINE void dc_top_predictor_8xh(uint16_t *dst, ptrdiff_t stride, int32_t height, const uint16_t *above) {
     const __m128i four = _mm_cvtsi32_si128(4);
     const __m128i sum  = dc_sum_8(above);
     const __m128i dc   = _mm_srli_epi16(_mm_add_epi16(sum, four), 3);
     dc_store_8xh(dst, stride, height, &dc);
 }
 
-void svt_aom_highbd_dc_top_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride,
-                                              const uint16_t *above, const uint16_t *left,
-                                              int32_t bd) {
+void svt_aom_highbd_dc_top_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                              const uint16_t *left, int32_t bd) {
     (void)left;
     (void)bd;
     dc_top_predictor_8xh(dst, stride, 4, above);
 }
 
-void svt_aom_highbd_dc_top_predictor_8x8_sse2(uint16_t *dst, ptrdiff_t stride,
-                                              const uint16_t *above, const uint16_t *left,
-                                              int32_t bd) {
+void svt_aom_highbd_dc_top_predictor_8x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                              const uint16_t *left, int32_t bd) {
     (void)left;
     (void)bd;
     dc_top_predictor_8xh(dst, stride, 8, above);
 }
 
-void svt_aom_highbd_dc_top_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride,
-                                               const uint16_t *above, const uint16_t *left,
-                                               int32_t bd) {
+void svt_aom_highbd_dc_top_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                               const uint16_t *left, int32_t bd) {
     (void)left;
     (void)bd;
     dc_top_predictor_8xh(dst, stride, 16, above);
@@ -436,9 +421,8 @@ static INLINE __m128i dc_sum_32(const uint16_t *ref) {
     return _mm_add_epi32(_mm_unpacklo_epi16(sum_a, zero), _mm_unpacklo_epi16(sum_b, zero));
 }
 
-void svt_aom_highbd_dc_left_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride,
-                                               const uint16_t *above, const uint16_t *left,
-                                               int32_t bd) {
+void svt_aom_highbd_dc_left_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                               const uint16_t *left, int32_t bd) {
     const __m128i two = _mm_cvtsi32_si128(2);
     const __m128i sum = dc_sum_4(left);
     const __m128i dc  = _mm_srli_epi16(_mm_add_epi16(sum, two), 2);
@@ -447,9 +431,8 @@ void svt_aom_highbd_dc_left_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride,
     dc_store_8xh(dst, stride, 4, &dc);
 }
 
-void svt_aom_highbd_dc_left_predictor_8x8_sse2(uint16_t *dst, ptrdiff_t stride,
-                                               const uint16_t *above, const uint16_t *left,
-                                               int32_t bd) {
+void svt_aom_highbd_dc_left_predictor_8x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                               const uint16_t *left, int32_t bd) {
     const __m128i four = _mm_cvtsi32_si128(4);
     const __m128i sum  = dc_sum_8(left);
     const __m128i dc   = _mm_srli_epi16(_mm_add_epi16(sum, four), 3);
@@ -458,9 +441,8 @@ void svt_aom_highbd_dc_left_predictor_8x8_sse2(uint16_t *dst, ptrdiff_t stride,
     dc_store_8xh(dst, stride, 8, &dc);
 }
 
-void svt_aom_highbd_dc_left_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride,
-                                                const uint16_t *above, const uint16_t *left,
-                                                int32_t bd) {
+void svt_aom_highbd_dc_left_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                                const uint16_t *left, int32_t bd) {
     const __m128i eight = _mm_cvtsi32_si128(8);
     const __m128i sum   = dc_sum_16(left);
     const __m128i dc    = _mm_srli_epi16(_mm_add_epi16(sum, eight), 4);
@@ -469,9 +451,8 @@ void svt_aom_highbd_dc_left_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride,
     dc_store_8xh(dst, stride, 16, &dc);
 }
 
-void svt_aom_highbd_dc_left_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride,
-                                                const uint16_t *above, const uint16_t *left,
-                                                int32_t bd) {
+void svt_aom_highbd_dc_left_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                                const uint16_t *left, int32_t bd) {
     const __m128i sixteen = _mm_cvtsi32_si128(16);
     const __m128i sum     = dc_sum_32(left);
     const __m128i dc      = _mm_srli_epi32(_mm_add_epi32(sum, sixteen), 5);
@@ -483,39 +464,34 @@ void svt_aom_highbd_dc_left_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride,
 // -----------------------------------------------------------------------------
 // DC_128
 
-static INLINE void dc_128_predictor_8xh(uint16_t *dst, ptrdiff_t stride, int32_t height,
-                                        int32_t bd) {
+static INLINE void dc_128_predictor_8xh(uint16_t *dst, ptrdiff_t stride, int32_t height, int32_t bd) {
     const __m128i dc = _mm_cvtsi32_si128(1 << (bd - 1));
     dc_store_8xh(dst, stride, height, &dc);
 }
 
-void svt_aom_highbd_dc_128_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride,
-                                              const uint16_t *above, const uint16_t *left,
-                                              int32_t bd) {
+void svt_aom_highbd_dc_128_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                              const uint16_t *left, int32_t bd) {
     (void)above;
     (void)left;
     dc_128_predictor_8xh(dst, stride, 4, bd);
 }
 
-void svt_aom_highbd_dc_128_predictor_8x8_sse2(uint16_t *dst, ptrdiff_t stride,
-                                              const uint16_t *above, const uint16_t *left,
-                                              int32_t bd) {
+void svt_aom_highbd_dc_128_predictor_8x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                              const uint16_t *left, int32_t bd) {
     (void)above;
     (void)left;
     dc_128_predictor_8xh(dst, stride, 8, bd);
 }
 
-void svt_aom_highbd_dc_128_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride,
-                                               const uint16_t *above, const uint16_t *left,
-                                               int32_t bd) {
+void svt_aom_highbd_dc_128_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                               const uint16_t *left, int32_t bd) {
     (void)above;
     (void)left;
     dc_128_predictor_8xh(dst, stride, 16, bd);
 }
 
-void svt_aom_highbd_dc_128_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride,
-                                               const uint16_t *above, const uint16_t *left,
-                                               int32_t bd) {
+void svt_aom_highbd_dc_128_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
+                                               const uint16_t *left, int32_t bd) {
     (void)above;
     (void)left;
     dc_128_predictor_8xh(dst, stride, 32, bd);
@@ -524,8 +500,8 @@ void svt_aom_highbd_dc_128_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride,
 // -----------------------------------------------------------------------------
 // V_PRED
 
-void svt_aom_highbd_v_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                         const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_v_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                         int32_t bd) {
     (void)left;
     (void)bd;
     const __m128i above_u16 = _mm_loadl_epi64((const __m128i *)above);
@@ -539,8 +515,8 @@ void svt_aom_highbd_v_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const
     }
 }
 
-void svt_aom_highbd_v_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                          const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_v_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                          int32_t bd) {
     (void)left;
     (void)bd;
     const __m128i above_u16 = _mm_loadl_epi64((const __m128i *)above);
@@ -554,8 +530,8 @@ void svt_aom_highbd_v_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const
     }
 }
 
-void svt_aom_highbd_v_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                         const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_v_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                         int32_t bd) {
     (void)left;
     (void)bd;
     const __m128i above_u16 = _mm_loadu_si128((const __m128i *)above);
@@ -565,8 +541,8 @@ void svt_aom_highbd_v_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const
     _mm_storeu_si128((__m128i *)(dst + 3 * stride), above_u16);
 }
 
-void svt_aom_highbd_v_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                          const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_v_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                          int32_t bd) {
     (void)left;
     (void)bd;
     const __m128i above_u16 = _mm_loadu_si128((const __m128i *)above);
@@ -580,8 +556,8 @@ void svt_aom_highbd_v_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, const
     }
 }
 
-void svt_aom_highbd_v_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                          const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_v_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                          int32_t bd) {
     (void)left;
     (void)bd;
     const __m128i above_u16 = _mm_loadu_si128((const __m128i *)above);
@@ -611,8 +587,8 @@ static INLINE __m128i dc_sum_8_32(const uint16_t *const src_8, const uint16_t *c
     return dc_sum_8x16bit_large(sum);
 }
 
-void svt_aom_highbd_dc_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                          const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_dc_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                          int32_t bd) {
     (void)bd;
     const __m128i sum_above = dc_sum_4(above);
     const __m128i sum_left  = dc_sum_8(left);
@@ -630,8 +606,8 @@ void svt_aom_highbd_dc_predictor_4x8_sse2(uint16_t *dst, ptrdiff_t stride, const
     }
 }
 
-void svt_aom_highbd_dc_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                           const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_dc_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                           int32_t bd) {
     (void)bd;
     __m128i       sum_above = dc_sum_4(above);
     __m128i       sum_left  = dc_sum_16(left);
@@ -652,8 +628,8 @@ void svt_aom_highbd_dc_predictor_4x16_sse2(uint16_t *dst, ptrdiff_t stride, cons
     }
 }
 
-void svt_aom_highbd_dc_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                          const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_dc_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                          int32_t bd) {
     (void)bd;
     const __m128i sum_left  = dc_sum_4(left);
     const __m128i sum_above = dc_sum_8(above);
@@ -672,8 +648,8 @@ void svt_aom_highbd_dc_predictor_8x4_sse2(uint16_t *dst, ptrdiff_t stride, const
     _mm_storeu_si128((__m128i *)dst, row);
 }
 
-void svt_aom_highbd_dc_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                           const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_dc_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                           int32_t bd) {
     (void)bd;
     __m128i       sum_left  = dc_sum_16(left);
     __m128i       sum_above = dc_sum_8(above);
@@ -698,8 +674,8 @@ void svt_aom_highbd_dc_predictor_8x16_sse2(uint16_t *dst, ptrdiff_t stride, cons
     }
 }
 
-void svt_aom_highbd_dc_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above,
-                                           const uint16_t *left, int32_t bd) {
+void svt_aom_highbd_dc_predictor_8x32_sse2(uint16_t *dst, ptrdiff_t stride, const uint16_t *above, const uint16_t *left,
+                                           int32_t bd) {
     (void)bd;
     const __m128i sum   = dc_sum_8_32(above, left);
     uint32_t      sum32 = _mm_cvtsi128_si32(sum);
