@@ -180,9 +180,9 @@ extern "C" {
     };
 
     /***************************************************************************
-    * av1_get_syntax_rate_from_cdf
+    * svt_aom_get_syntax_rate_from_cdf
     ***************************************************************************/
-    extern void av1_get_syntax_rate_from_cdf(
+    extern void svt_aom_get_syntax_rate_from_cdf(
         int32_t                        *costs,
         const AomCdfProb             *cdf,
         const int32_t                  *inv_map);
@@ -190,30 +190,29 @@ extern "C" {
     * Estimate the rate for each syntax elements and for
     * all scenarios based on the frame CDF
     ***************************************************************************/
-    extern void av1_estimate_syntax_rate(
-        MdRateEstimationContext      *md_rate_estimation_array,
+    extern void svt_aom_estimate_syntax_rate(
+        MdRateEstimationContext      *md_rate_est_ctx,
         Bool                          is_i_slice,
         uint8_t pic_filter_intra_level,
         uint8_t allow_screen_content_tools,
         uint8_t enable_restoration,
         uint8_t allow_intrabc,
-        uint8_t partition_contexts,
         FRAME_CONTEXT                  *fc);
     /**************************************************************************
     * Estimate the rate of the quantised coefficient
     * based on the frame CDF
     ***************************************************************************/
-    extern void av1_estimate_coefficients_rate(
-        MdRateEstimationContext  *md_rate_estimation_array,
+    extern void svt_aom_estimate_coefficients_rate(
+        MdRateEstimationContext  *md_rate_est_ctx,
         FRAME_CONTEXT              *fc);
     /**************************************************************************
-    * av1_estimate_mv_rate()
+    * svt_aom_estimate_mv_rate()
     * Estimate the rate of motion vectors
     * based on the frame CDF
     ***************************************************************************/
-extern void av1_estimate_mv_rate(
-        struct PictureControlSet *pcs_ptr,
-        MdRateEstimationContext  *md_rate_estimation_array,
+extern void svt_aom_estimate_mv_rate(
+        struct PictureControlSet *pcs,
+        MdRateEstimationContext  *md_rate_est_ctx,
         FRAME_CONTEXT            *fc);
 #define AVG_CDF_WEIGHT_LEFT      3
 #define AVG_CDF_WEIGHT_TOP       1
@@ -395,16 +394,16 @@ static AOM_INLINE void avg_cdf_symbols(FRAME_CONTEXT *ctx_left,
 /*******************************************************************************
  * Updates all the syntax stats/CDF for the current block
  ******************************************************************************/
-void update_stats(
-    struct PictureControlSet   *pcs_ptr,
+void svt_aom_update_stats(
+    struct PictureControlSet   *pcs,
     struct BlkStruct          *blk_ptr,
     int                         mi_row,
     int                         mi_col);
 /*******************************************************************************
  * Updates the partition stats/CDF for the current block
  ******************************************************************************/
-void update_part_stats(
-    struct PictureControlSet   *pcs_ptr,
+void svt_aom_update_part_stats(
+    struct PictureControlSet   *pcs,
     struct BlkStruct          *blk_ptr,
     uint16_t                    tile_idx,
     int                         mi_row,
@@ -414,7 +413,7 @@ void update_part_stats(
 * Returns the me-based qindex (used for lambda modulation only; not at Q/Q-1)
 */
 uint8_t svt_aom_get_me_qindex(
-    struct PictureControlSet* pcs_ptr,
+    struct PictureControlSet* pcs,
     struct SuperBlock* sb_ptr,
     uint8_t is_sb128);
 
