@@ -14,10 +14,20 @@
 #include "EbSequenceControlSet.h"
 #include "EbUtility.h"
 
+static void free_scale_evts(SvtAv1FrameScaleEvts *evts) {
+    EB_FREE_ARRAY(evts->resize_denoms);
+    EB_FREE_ARRAY(evts->resize_kf_denoms);
+    EB_FREE_ARRAY(evts->start_frame_nums);
+    evts->evt_num = 0;
+}
+
 static void svt_sequence_control_set_dctor(EbPtr p) {
     SequenceControlSet *obj = (SequenceControlSet *)p;
+    if (!obj)
+        return;
     EB_FREE_ARRAY(obj->b64_geom);
     EB_FREE_ARRAY(obj->sb_geom);
+    free_scale_evts(&obj->static_config.frame_scale_evts);
 }
 /**************************************************************************************************
     General notes on how Sequence Control Sets (SCS) are used.
@@ -91,8 +101,7 @@ EbErrorType svt_sequence_control_set_ctor(SequenceControlSet *scs, EbPtr object_
 
     return EB_ErrorNone;
 }
-extern EbErrorType derive_input_resolution(EbInputResolution *input_resolution,
-                                           uint32_t           inputSize) {
+extern EbErrorType svt_aom_derive_input_resolution(EbInputResolution *input_resolution, uint32_t inputSize) {
     EbErrorType return_error = EB_ErrorNone;
     if (inputSize < INPUT_SIZE_240p_TH)
         *input_resolution = INPUT_SIZE_240p_RANGE;
@@ -114,21 +123,22 @@ extern EbErrorType derive_input_resolution(EbInputResolution *input_resolution,
 
 static void svt_sequence_control_set_instance_dctor(EbPtr p) {
     EbSequenceControlSetInstance *obj = (EbSequenceControlSetInstance *)p;
-    EB_DELETE(obj->encode_context_ptr);
-    EB_DELETE(obj->scs_ptr);
+    EB_DELETE(obj->enc_ctx);
+    EB_DESTROY_SEMAPHORE(obj->scs->ref_buffer_available_semaphore);
+    EB_DELETE(obj->scs);
 }
 
 EbErrorType svt_sequence_control_set_instance_ctor(EbSequenceControlSetInstance *object_ptr) {
     object_ptr->dctor = svt_sequence_control_set_instance_dctor;
 
-    EB_NEW(object_ptr->encode_context_ptr, encode_context_ctor, NULL);
-    EB_NEW(object_ptr->scs_ptr, svt_sequence_control_set_ctor, NULL);
-    object_ptr->scs_ptr->encode_context_ptr = object_ptr->encode_context_ptr;
+    EB_NEW(object_ptr->enc_ctx, svt_aom_encode_context_ctor, NULL);
+    EB_NEW(object_ptr->scs, svt_sequence_control_set_ctor, NULL);
+    object_ptr->scs->enc_ctx = object_ptr->enc_ctx;
 
     return EB_ErrorNone;
 }
 
-extern EbErrorType b64_geom_init(SequenceControlSet *scs) {
+extern EbErrorType svt_aom_b64_geom_init(SequenceControlSet *scs) {
     EbErrorType return_error = EB_ErrorNone;
     uint16_t    b64_idx;
     uint16_t    raster_scan_blk_index;
@@ -144,34 +154,33 @@ extern EbErrorType b64_geom_init(SequenceControlSet *scs) {
         B64Geom *b64_geom          = &scs->b64_geom[b64_idx];
         b64_geom->horizontal_index = (uint8_t)(b64_idx % picture_b64_width);
         b64_geom->vertical_index   = (uint8_t)(b64_idx / picture_b64_width);
-        b64_geom->origin_x         = b64_geom->horizontal_index * b64_size;
-        b64_geom->origin_y         = b64_geom->vertical_index * b64_size;
+        b64_geom->org_x            = b64_geom->horizontal_index * b64_size;
+        b64_geom->org_y            = b64_geom->vertical_index * b64_size;
 
-        b64_geom->width = (uint8_t)(((scs->max_input_luma_width - b64_geom->origin_x) < b64_size)
-                                        ? scs->max_input_luma_width - b64_geom->origin_x
+        b64_geom->width = (uint8_t)(((scs->max_input_luma_width - b64_geom->org_x) < b64_size)
+                                        ? scs->max_input_luma_width - b64_geom->org_x
                                         : b64_size);
 
-        b64_geom->height = (uint8_t)(((scs->max_input_luma_height - b64_geom->origin_y) < b64_size)
-                                         ? scs->max_input_luma_height - b64_geom->origin_y
+        b64_geom->height = (uint8_t)(((scs->max_input_luma_height - b64_geom->org_y) < b64_size)
+                                         ? scs->max_input_luma_height - b64_geom->org_y
                                          : b64_size);
 
-        b64_geom->is_complete_b64 =
-            (uint8_t)(((b64_geom->width == b64_size) && (b64_geom->height == b64_size)) ? 1 : 0);
+        b64_geom->is_complete_b64 = (uint8_t)(((b64_geom->width == b64_size) && (b64_geom->height == b64_size)) ? 1
+                                                                                                                : 0);
 
-        b64_geom->is_edge_sb = (b64_geom->origin_x < b64_size) || (b64_geom->origin_y < b64_size) ||
-                (b64_geom->origin_x > scs->max_input_luma_width - b64_size) ||
-                (b64_geom->origin_y > scs->max_input_luma_height - b64_size)
+        b64_geom->is_edge_sb = (b64_geom->org_x < b64_size) || (b64_geom->org_y < b64_size) ||
+                (b64_geom->org_x > scs->max_input_luma_width - b64_size) ||
+                (b64_geom->org_y > scs->max_input_luma_height - b64_size)
             ? 1
             : 0;
 
-        for (raster_scan_blk_index = RASTER_SCAN_CU_INDEX_64x64;
-             raster_scan_blk_index <= RASTER_SCAN_CU_INDEX_8x8_63;
+        for (raster_scan_blk_index = RASTER_SCAN_CU_INDEX_64x64; raster_scan_blk_index <= RASTER_SCAN_CU_INDEX_8x8_63;
              raster_scan_blk_index++) {
             b64_geom->raster_scan_blk_validity[raster_scan_blk_index] =
-                ((b64_geom->origin_x + raster_scan_blk_x[raster_scan_blk_index] +
+                ((b64_geom->org_x + raster_scan_blk_x[raster_scan_blk_index] +
                       raster_scan_blk_size[raster_scan_blk_index] >
                   scs->max_input_luma_width) ||
-                 (b64_geom->origin_y + raster_scan_blk_y[raster_scan_blk_index] +
+                 (b64_geom->org_y + raster_scan_blk_y[raster_scan_blk_index] +
                       raster_scan_blk_size[raster_scan_blk_index] >
                   scs->max_input_luma_height))
                 ? FALSE
@@ -186,94 +195,67 @@ extern EbErrorType b64_geom_init(SequenceControlSet *scs) {
     return return_error;
 }
 
-EbErrorType rtime_alloc_sb_geom(SequenceControlSet *scs_ptr, uint32_t size) {
-    EB_MALLOC_ARRAY(scs_ptr->sb_geom, size);
+EbErrorType rtime_alloc_sb_geom(SequenceControlSet *scs, uint32_t size) {
+    EB_MALLOC_ARRAY(scs->sb_geom, size);
     return EB_ErrorNone;
 }
-EbErrorType sb_geom_init(SequenceControlSet *scs_ptr) {
+EbErrorType svt_aom_sb_geom_init(SequenceControlSet *scs) {
     uint16_t sb_index;
     uint16_t md_scan_block_index;
-    uint16_t picture_sb_width = (scs_ptr->max_input_luma_width + scs_ptr->sb_size - 1) /
-        scs_ptr->sb_size;
-    uint16_t picture_sb_height = (scs_ptr->max_input_luma_height + scs_ptr->sb_size - 1) /
-        scs_ptr->sb_size;
+    uint16_t picture_sb_width  = (scs->max_input_luma_width + scs->sb_size - 1) / scs->sb_size;
+    uint16_t picture_sb_height = (scs->max_input_luma_height + scs->sb_size - 1) / scs->sb_size;
 
-    EB_FREE_ARRAY(scs_ptr->sb_geom);
-    rtime_alloc_sb_geom(scs_ptr, picture_sb_width * picture_sb_height);
+    EB_FREE_ARRAY(scs->sb_geom);
+    rtime_alloc_sb_geom(scs, picture_sb_width * picture_sb_height);
 
     for (sb_index = 0; sb_index < picture_sb_width * picture_sb_height; ++sb_index) {
-        scs_ptr->sb_geom[sb_index].horizontal_index = sb_index % picture_sb_width;
-        scs_ptr->sb_geom[sb_index].vertical_index   = sb_index / picture_sb_width;
-        scs_ptr->sb_geom[sb_index].origin_x         = scs_ptr->sb_geom[sb_index].horizontal_index *
-            scs_ptr->sb_size;
-        scs_ptr->sb_geom[sb_index].origin_y = scs_ptr->sb_geom[sb_index].vertical_index *
-            scs_ptr->sb_size;
+        scs->sb_geom[sb_index].horizontal_index = sb_index % picture_sb_width;
+        scs->sb_geom[sb_index].vertical_index   = sb_index / picture_sb_width;
+        scs->sb_geom[sb_index].org_x            = scs->sb_geom[sb_index].horizontal_index * scs->sb_size;
+        scs->sb_geom[sb_index].org_y            = scs->sb_geom[sb_index].vertical_index * scs->sb_size;
 
-        scs_ptr->sb_geom[sb_index].width =
-            (uint8_t)(((scs_ptr->max_input_luma_width - scs_ptr->sb_geom[sb_index].origin_x) <
-                       scs_ptr->sb_size)
-                          ? scs_ptr->max_input_luma_width - scs_ptr->sb_geom[sb_index].origin_x
-                          : scs_ptr->sb_size);
+        scs->sb_geom[sb_index].width = (uint8_t)(((scs->max_input_luma_width - scs->sb_geom[sb_index].org_x) <
+                                                  scs->sb_size)
+                                                     ? scs->max_input_luma_width - scs->sb_geom[sb_index].org_x
+                                                     : scs->sb_size);
 
-        scs_ptr->sb_geom[sb_index].height =
-            (uint8_t)(((scs_ptr->max_input_luma_height - scs_ptr->sb_geom[sb_index].origin_y) <
-                       scs_ptr->sb_size)
-                          ? scs_ptr->max_input_luma_height - scs_ptr->sb_geom[sb_index].origin_y
-                          : scs_ptr->sb_size);
+        scs->sb_geom[sb_index].height = (uint8_t)(((scs->max_input_luma_height - scs->sb_geom[sb_index].org_y) <
+                                                   scs->sb_size)
+                                                      ? scs->max_input_luma_height - scs->sb_geom[sb_index].org_y
+                                                      : scs->sb_size);
 
-        scs_ptr->sb_geom[sb_index].is_complete_sb =
-            (uint8_t)(((scs_ptr->sb_geom[sb_index].width == scs_ptr->sb_size) &&
-                       (scs_ptr->sb_geom[sb_index].height == scs_ptr->sb_size))
-                          ? 1
-                          : 0);
+        scs->sb_geom[sb_index].is_complete_sb = (uint8_t)(((scs->sb_geom[sb_index].width == scs->sb_size) &&
+                                                           (scs->sb_geom[sb_index].height == scs->sb_size))
+                                                              ? 1
+                                                              : 0);
 
-        uint16_t max_block_count = scs_ptr->max_block_cnt;
+        uint16_t max_block_count = scs->max_block_cnt;
 
-        for (md_scan_block_index = 0; md_scan_block_index < max_block_count;
-             md_scan_block_index++) {
+        for (md_scan_block_index = 0; md_scan_block_index < max_block_count; md_scan_block_index++) {
             const BlockGeom *blk_geom = get_blk_geom_mds(md_scan_block_index);
-            if (scs_ptr->over_boundary_block_mode == 1) {
-                scs_ptr->sb_geom[sb_index].block_is_allowed[md_scan_block_index] =
-                    ((scs_ptr->sb_geom[sb_index].origin_x + blk_geom->origin_x +
-                          blk_geom->bwidth / 2 <
-                      scs_ptr->max_input_luma_width) &&
-                     (scs_ptr->sb_geom[sb_index].origin_y + blk_geom->origin_y +
-                          blk_geom->bheight / 2 <
-                      scs_ptr->max_input_luma_height))
+            if (scs->over_boundary_block_mode == 1) {
+                scs->sb_geom[sb_index].block_is_allowed[md_scan_block_index] =
+                    ((scs->sb_geom[sb_index].org_x + blk_geom->org_x + blk_geom->bwidth / 2 <
+                      scs->max_input_luma_width) &&
+                     (scs->sb_geom[sb_index].org_y + blk_geom->org_y + blk_geom->bheight / 2 <
+                      scs->max_input_luma_height))
                     ? TRUE
                     : FALSE;
 
-                if (blk_geom->shape != PART_N)
-                    blk_geom = get_blk_geom_mds(blk_geom->sqi_mds);
-                scs_ptr->sb_geom[sb_index].block_is_inside_md_scan[md_scan_block_index] =
-                    ((scs_ptr->sb_geom[sb_index].origin_x >= scs_ptr->max_input_luma_width) ||
-                     (scs_ptr->sb_geom[sb_index].origin_y >= scs_ptr->max_input_luma_height))
-                    ? FALSE
-                    : TRUE;
             } else {
                 if (blk_geom->shape != PART_N)
                     blk_geom = get_blk_geom_mds(blk_geom->sqi_mds);
 
-                scs_ptr->sb_geom[sb_index].block_is_allowed[md_scan_block_index] =
-                    ((scs_ptr->sb_geom[sb_index].origin_x + blk_geom->origin_x + blk_geom->bwidth >
-                      scs_ptr->max_input_luma_width) ||
-                     (scs_ptr->sb_geom[sb_index].origin_y + blk_geom->origin_y + blk_geom->bheight >
-                      scs_ptr->max_input_luma_height))
-                    ? FALSE
-                    : TRUE;
-
-                scs_ptr->sb_geom[sb_index].block_is_inside_md_scan[md_scan_block_index] =
-                    ((scs_ptr->sb_geom[sb_index].origin_x + blk_geom->origin_x + blk_geom->bwidth >
-                      scs_ptr->max_input_luma_width) ||
-                     (scs_ptr->sb_geom[sb_index].origin_y + blk_geom->origin_y + blk_geom->bheight >
-                      scs_ptr->max_input_luma_height))
+                scs->sb_geom[sb_index].block_is_allowed[md_scan_block_index] =
+                    ((scs->sb_geom[sb_index].org_x + blk_geom->org_x + blk_geom->bwidth > scs->max_input_luma_width) ||
+                     (scs->sb_geom[sb_index].org_y + blk_geom->org_y + blk_geom->bheight > scs->max_input_luma_height))
                     ? FALSE
                     : TRUE;
             }
         }
     }
 
-    scs_ptr->sb_total_count = picture_sb_width * picture_sb_height;
+    scs->sb_total_count = picture_sb_width * picture_sb_height;
 
     return 0;
 }
